Labels failed matches as such in the provided Scottish post office directory data.frame.
combine_label_failed_matches(directory)A Scottish post office directory in the form of a data.frame
or other object that inherits from the data.frame class such as a
tibble. Columns must at least include
address.house.number, address.house.body.
A data.frame of the same class as the one provided in directory.
Columns include address.house.number, address.house.body. For entries
for which both address.house.number and address.house.body are NA,
address.house.number and address.house.body are labelled as "" and
"Failed to match with general directory" respectively.