Attempts to complement Scottish post office trades directory data.frame with house address information from the Scottish post office general directory data.frame provided by matching records from the two datasets using the distance metric specified. Shows a progress bar indicating function progression.
combine_match_general_to_trades_progress(
trades_directory,
general_directory,
verbose,
matches,
...
)A Scottish post office trades directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
surname, forename, address.trade.number, address.trade.body.
A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
surname, forename, address.trade.number, address.trade.body,
address.house.number, address.house.body.
Whether the function should be executed silently (FALSE) or
not (TRUE).
Whether (TRUE) or not (FALSE) a column 'match' showing
general directory matches' name and address(es) should be added to the
output dataset.
Further arguments to be passed down to
stringdist_left_join.
A data.frame of the same class as that of the one provided in
trades_directory and/or general_directory. Should trades_directory and
general_directorybe provided as objects of different classes, the class of
the return data.frame will be that of the parent class. i.e. if
trades_directory and general_directory are provided as a pure data.frame
and a tibble respectively, a pure data.frame is
returned. Columns include at least surname, forename,
address.trade.number, address.trade.body, address.house.number,
address.house.body.