Replaces missing trade address(es) in the provided Scottish post office directory data.frame with random string(s). Random string(s) only show(s) in body of trade address entry(/ies).
combine_no_trade_address_to_random_string(directory)A Scottish post office directory in the form of a data.frame
or other object that inherits from the data.frame class such as a
tibble. Columns must at least include address.trade.
A data.frame of the same class as the one provided in directory;
columns include at least address.trade.
Prevents unwarranted matches when matching general to trades directory. Unrelated records with similar name and trade address entry labelled as missing would be otherwise matched.