Learn R Programming

podcleaner (version 0.1.2)

combine_random_string_if_no_address: Conditionally return a random string

Description

Returns a 22 character long random string if address provided is labelled as missing ("No trade/house address found").

Usage

combine_random_string_if_no_address(address)

Arguments

address

A character string.

Value

A length 1 character string vector: 22 character long random string if address labelled as missing ("No trade/house address found"), address otherwise.