Attempts to clean entries of the provided Scottish post office general directory data.frame provided.
general_clean_entries(directory, verbose)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
forename, surname, occupation, address.trade.number,
address.trade.body and/or address.house.number, address.house.body.
Whether the function should be executed silently (FALSE) or
not (TRUE).
A data.frame of the same class as the one provided in directory;
columns include the same as those in the data.frame provided in
directory. Entries are cleaned of optical character recognition (OCR)
errors and subject to a number of standardisation operations.