For some raw Scottish post office general directory entries, the word "house"
referring to address type lives in the occupation column as a result of
parsing errors. general_move_house_to_address attempts to move this
information to the appropriate destination: the addresses column.
general_move_house_to_address(directory, regex)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
occupation and addresses.
Regex to use for the task provided as a character string.
A data.frame of the same class as the one provided in directory;
columns include at least occupation and addresses. Entries in the
occupation column are cleaned of "house" suffix; entries showing "house"
suffix in occupation column see "house, " pasted as prefix to
corresponding addresses column content.