For some raw Scottish post office general directory entries occupation
information lives in the addresses column as a result of parsing errors.
general_repatriate_occupation_from_address attempts to move this
information to the appropriate destination: the occupation column.
general_repatriate_occupation_from_address(directory, regex)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
occupation and addresses.
Regex to use for the task provided as a character string.
A data.frame of the same class as the one provided in directory;
columns include at least occupation and addresses.