Attempts to separate number from body of address entries in the Scottish post office general directory data.frame provided
general_split_address_numbers_bodies(
directory,
regex_split_address_numbers,
regex_split_address_body,
regex_split_address_empty,
ignore_case_filter,
ignore_case_match
)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
address.trade and address.house.
Regex to use to match address number(s).
Regex to use to match address body(/ies).
Regex to use to match empty address entries.
Boolean specifying whether case should be ignored
(TRUE) or not (FALSE) for using one of the regexes above as filtering
regex in utils_regmatches_if_found.
Boolean specifying whether case should be ignored
(TRUE) or not (FALSE) for using one of the regexes above as matching
regex in utils_regmatches_if_found.
A data.frame of the same class as the one provided in directory;
columns include at least address.trade.number, address.trade.body,
address.house.number and address.house.body.