Attempts to separate multiple trade addresses in the Scottish post office general directory data.frame provided for entries for which more than one are provided.
general_split_trade_addresses(
directory,
regex_split,
ignore_case_split,
regex_filter,
ignore_case_filter,
regex_match,
ignore_case_match
)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
addresses.trade.
Regex to use to split addresses.
Boolean specifying whether case should be ignored
(TRUE) or not (FALSE) for regex_split above.
Regex to use to search for address entries with post-split undesired leftovers.
Boolean specifying whether case should be ignored
(TRUE) or not (FALSE) for regex_filter above.
Regex to use to clear address entries from post-split undesired leftovers.
Boolean specifying whether case should be ignored
(TRUE) or not (FALSE) for regex_match above.
A data.frame of the same class as the one provided in directory;
columns include at least address.trade. Multiple trade addresses are
separated for entries for which more than one are provided. Each trade
address identified lives on an individual row with information in the other
columns duplicated.