Attempts to separate house address from trade address(es) in the Scottish post office general directory data.frame provided for entries for which a house address is provided along trade address(es).
general_split_trade_house_addresses(directory, regex, verbose)A Scottish post office general directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
addresses.
Regex to use for the task provided as a character string.
Whether the function should be executed silently (FALSE) or
not (TRUE).
A data.frame of the same class as the one provided in directory;
columns include at least addresses.trade and address.house. Trade
addresses are separated from house address for entries for which a house
address is provided along trade address(es).