A dataset containing regular expression meant to match commonly (OCR) misread place names in directory address entries. For each place name a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_address_namesA data frame with 3 variables:
regex for place name matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.