A dataset containing regular expression meant to match common (OCR) errors in reading the ampersand character: "&" in directory entries. For each error pattern a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_ampersandA data frame with 3 variables:
regex for ampersand reading error matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.