A dataset containing regular expression meant to match commonly (OCR) misread "Mac" pre-fixes in directory name entries. For each "Mac" pre-fix a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_macsA data frame with 3 variables:
regex for "Mac" pre-fix matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.