A dataset containing regular expression meant to match commonly (OCR) misread place types in directory address entries. For each place type a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_places_regexA data frame with 3 variables:
regex for place type matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.