Learn R Programming

podcleaner (version 0.1.2)

globals_regex_address_house_body_number: Regular expression for mutate operations in directory datasets

Description

Regular expression used in the making of the match.string that eventually enables the matching of general and trades directory records.

Usage

globals_regex_address_house_body_number

Arguments

Format

A character string vector.

See Also

combine_label_failed_matches