A dataset containing regular expression meant to match commonly (OCR) misread name of Saints in directory address names. For each Saint a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_saintsA data frame with 3 variables:
regex for Saint name matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.