A dataset containing regular expression meant to match commonly (OCR) misread suffixes in directory address entries. For each suffix a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_suffixesA data frame with 3 variables:
regex for suffix matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.