A dataset containing regular expression meant to match commonly (OCR) misread surnames in directory name entries. For each surname a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_surnamesA data frame with 3 variables:
regex for surname matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.