Learn R Programming

podcleaner (version 0.1.2)

globals_titles: Titles in directory name records

Description

A dataset containing regular expression meant to match commonly (OCR) misread titles in directory name records. For each title a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.

Usage

globals_titles

Arguments

Format

A data frame with 3 variables:

pattern

regex for title matching

replacement

replacement pattern for substitution operations

ignore_case

boolean operator indicating whether the corresponding regex is case sensitive or not.