A dataset containing regular expression meant to match commonly (OCR) misread worksite names in directory address entries. For each worksite a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_worksitesA data frame with 3 variables:
regex for worksite name matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.