Attempts to clean the provided Scottish post office trades directory data.frame. Shows a progress bar indicating function progression.
trades_clean_directory_progress(directory, verbose)A Scottish post office trades directory in the form
of a data.frame or other object that inherits from the data.frame class
such as a tibble. Columns must at least include
forename, surname, occupation``address.trade.number and
address.trade.body.
Whether the function should be executed silently (FALSE) or
not (TRUE).
A data.frame of the same class as the one provided in directory;
columns include at least forename, surname, occupation,
address.trade.number and address.trade.body. Entries are cleaned of
optical character recognition (OCR) errors and subject to a number of
standardisation operations.