A dataset containing regular expression meant to match commonly (OCR) misread titles in directory name records. For each title a replacement pattern is provided for used in substitution operations as well as a boolean operator indicating whether the corresponding regex is case sensitive or not.
globals_titlesA data frame with 3 variables:
regex for title matching
replacement pattern for substitution operations
boolean operator indicating whether the corresponding regex is case sensitive or not.