utils_regmatches_if_not_empty: Conditionally amend character string vector.
Description
Searches for non-empty string in provided character string vector. If found
searches for alternative pattern in an alternative character string and
returns any match or an empty string if none.